@@ -25,10 +25,12 @@
 
 namespace Dasher {
 
+  /// \ingroup LM
+  /// \{
+
   ///
   /// Language model using words
   ///
-
   class CWordLanguageModel:public CLanguageModel {
   public:
     CWordLanguageModel(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, const CSymbolAlphabet & Alphabet);
@@ -38,7 +40,7 @@ namespace Dasher {
     void ReleaseContext(Context context);
     Context CloneContext(Context context);
 
-    virtual void GetProbs(Context Context, std::vector < unsigned int >&Probs, int iNorm) const;
+    virtual void GetProbs(Context Context, std::vector < unsigned int >&Probs, int iNorm, int iUniform) const;
 
     virtual void EnterSymbol(Context context, int Symbol);
     virtual void LearnSymbol(Context context, int Symbol);
@@ -130,6 +132,7 @@ namespace Dasher {
     mutable CSimplePooledAlloc < CWordnode > m_NodeAlloc;
     CPooledAlloc < CWordContext > m_ContextAlloc;
   };
+  /// \}
 
 ////////////////////////////////////////////////////////////////////////
 // Inline functions 
