@@ -286,7 +286,7 @@ void CEdit::TNew(const Tstring &filename) {
   AppendMode = false;
   Clear();
 
-  m_pDasherInterface->InvalidateContext(true);
+//  m_pDasherInterface->InvalidateContext(true);
 }
 
 bool CEdit::TOpen(const Tstring &filename) {
@@ -823,7 +823,7 @@ LRESULT CEdit::OnLButtonDown(UINT message, WPARAM wParam, LPARAM lParam, BOOL& b
 
 LRESULT CEdit::OnLButtonUp(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
 {
-  m_pDasherInterface->InvalidateContext(false);
+//  m_pDasherInterface->InvalidateContext(false);
 
 	bHandled = FALSE; // let the EDIT class handle it
 	return 0;
